Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/collada/LightExporter.cpp')
-rw-r--r--source/blender/collada/LightExporter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/collada/LightExporter.cpp b/source/blender/collada/LightExporter.cpp
index 215775b1758..c1822a8e5f3 100644
--- a/source/blender/collada/LightExporter.cpp
+++ b/source/blender/collada/LightExporter.cpp
@@ -29,7 +29,7 @@
#include "collada_internal.h"
template<class Functor>
-void forEachLampObjectInExportSet(Scene *sce, Functor &f, LinkNode *export_set)
+void forEachLightObjectInExportSet(Scene *sce, Functor &f, LinkNode *export_set)
{
LinkNode *node;
for (node = export_set; node; node = node->next) {
@@ -48,7 +48,7 @@ void LightsExporter::exportLights(Scene *sce)
{
openLibrary();
- forEachLampObjectInExportSet(sce, *this, this->export_settings->export_set);
+ forEachLightObjectInExportSet(sce, *this, this->export_settings->export_set);
closeLibrary();
}
@@ -105,7 +105,7 @@ void LightsExporter::operator()(Object *ob)
exportBlenderProfile(cla, la);
addLight(cla);
}
// area lamp is not supported
// it will be exported as a local lamp
else {
COLLADASW::PointLight cla(mSW, la_id, la_name);
@@ -105,7 +105,7 @@ void LightsExporter::operator()(Object *ob)
addLight(cla);
}
- // area lamp is not supported
+ // area light is not supported
// it will be exported as a local lamp
else {